-- -------------------------------------------------------------------------
-- mysql-db scripts for create tables
-- @autor marc at bouquet dot ch
-- Copyright (c) 2007 Marc Bouquet, 3032 Hinterkappelen. All rights reseved.
-- -------------------------------------------------------------------------

create database if not exists eadj;
use eadj;

-- -------------------------------------------------------------------------
-- drop tables
-- -------------------------------------------------------------------------

drop table if exists auth_user_role;
drop table if exists auth_role;
drop table if exists search;
drop table if exists subscriber;
drop table if exists auth_user;

-- -------------------------------------------------------------------------
-- create table auth_user
-- -------------------------------------------------------------------------
create table auth_user (
  auth_user_id          	int unsigned 	not null auto_increment,
  login        				varchar(1024) 	not null,
  password         			varchar(2048) 	not null,
  encryption_version		varchar(80) 	not null,
  state						int unsigned 	not null,
  last_login_dat			timestamp 		null,
  
  primary key  (auth_user_id)
) engine=InnoDB default charset=latin1;



-- -------------------------------------------------------------------------
-- create table auth_role
-- -------------------------------------------------------------------------
create table auth_role (
  auth_role_id				int unsigned 	not null auto_increment,
  name						varchar(80) 	not null,
  
  primary key  (auth_role_id)
) engine=InnoDB default charset=latin1;



-- -------------------------------------------------------------------------
-- create relationship table auth_user_role
--
-- note: 
--  (1) a auth_role may have * auth_user entries but a auth_user
--      entry belongs to one auth_role.
--  (2) to enforce this constraint, a uniqe index is defined for the
--      auth_user_id row
-- -------------------------------------------------------------------------
create table auth_user_role (
  auth_user_id       		int unsigned 	not null,
  auth_role_id       		int unsigned 	not null,
  
  unique(auth_user_id),
  FOREIGN KEY (auth_user_id) REFERENCES auth_user(auth_user_id) ON DELETE CASCADE,
  FOREIGN KEY (auth_role_id) REFERENCES auth_role(auth_role_id) ON DELETE CASCADE 

) engine=InnoDB default charset=latin1;



-- -------------------------------------------------------------------------
-- create table subscriber
-- -------------------------------------------------------------------------
create table subscriber (
  subscriber_id				int unsigned 	not null auto_increment,
  auth_user_id				int unsigned 	not null,
  first_name        		varchar(120) 	null,
  last_name					varchar(120) 	null,
  email_address				varchar(200) 	not null,
  address					varchar(400) 	null,
  zip						varchar(40) 	null,
  city						varchar(120) 	null,
  country					varchar(8) 		null,
  version					int unsigned 	not null,
  
  primary key  (subscriber_id),
  FOREIGN KEY (auth_user_id) REFERENCES auth_user(auth_user_id) ON DELETE CASCADE
) engine=InnoDB default charset=latin1;


-- -------------------------------------------------------------------------
-- create table search
-- -------------------------------------------------------------------------
create table search (
  search_id					int unsigned 	not null auto_increment,
  subscriber_id				int unsigned 	not null,
  name        				varchar(120) 	not null,
  criteria					varchar(400) 	not null,
  state						varchar(10) 	not null,
  frequency					varchar(10) 	null,
  output_format				varchar(10) 	null,
  start_dat					timestamp		null,
  
  primary key  (search_id),
  FOREIGN KEY (subscriber_id) REFERENCES subscriber(subscriber_id) ON DELETE CASCADE
) engine=InnoDB default charset=latin1;