/** Copyright (c) 2007 bouquet dot ch, 3032 hinterkappelen. All rights reseved. 
 * Alle Rechte vorbehalten. Reproduktion zu nicht kommerziellem Gebrauch mit Quellenangabe 
 * gestattet. Reproduktion (auch auszugsweise) zum kommerziellen Gebrauch für Vortragszwecke 
 * sind nur mit schriftlicher Bewilligung des Verfassers gestattet.
 */
package ch.bouquet.jpa.domain;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;

import org.apache.log4j.Logger;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Data-Tier (JPA)<br/>
 * User admininstration (examination question)<br/>
 * Description:<br/>
 * Authenticated role business object implemented as plain old java object.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Swiss )
 * @version   1.0 - 25.05.2007
 */
@Entity
@Table( name = "auth_role" )
public class AuthRole implements Serializable
{
  /**
   * constant for the logging
   */
  @SuppressWarnings( "unused" )
  private static Logger LOG = Logger.getLogger( AuthRole.class );

  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * auth role id (primary key)
   */
  @Id
  @GeneratedValue
  @Column( name = "AUTH_ROLE_ID" )
  private long authRoleId;

  /**
   * role name
   */
  @Column( name = "name" )
  private String name;

  //-----------------------------------------------------------------------------
  // C O N S T R U C T O R S
  //-----------------------------------------------------------------------------

  /**
   * Default constructor
   */
  public AuthRole()
  {
    // Don't do anything
  }

  /**
   * Constructor
   * @param name String
   */
  public AuthRole( String name )
  {
    setName( name );
  }

  //---------------------------------------------------------------------------
  // toString() method
  //---------------------------------------------------------------------------

  /**
   * Return all attributes as String
   * @return Object as String
   */
  @Override
  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append( " --- toString() of ch.bouquet.jpa.domain.AuthRole ------------------------\n" );
    buf.append( "  authRoleId             <" );
    buf.append( getAuthRoleId() );
    buf.append( ">\n" );
    buf.append( "  name                   <" );
    buf.append( getName() );
    buf.append( ">" );
    return buf.toString();
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - / S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Gets the authRoleId.
   * @return the authRoleId
   */
  public long getAuthRoleId()
  {
    return this.authRoleId;
  }

  /**
   * Sets the authRoleId.
   * @param authRoleId The authRoleId to set
   */
  public void setAuthRoleId( long authRoleId )
  {
    this.authRoleId = authRoleId;
  }

  /**
   * Gets the name.
   * @return the name
   */
  public String getName()
  {
    return this.name;
  }

  /**
   * Sets the name.
   * @param name The name to set
   */
  public void setName( String name )
  {
    this.name = name;
  }
}
