/** Copyright (c) 2007 bouquet dot ch, 3032 hinterkappelen. All rights reseved. 
 * Alle Rechte vorbehalten. Reproduktion zu nicht kommerziellem Gebrauch mit Quellenangabe 
 * gestattet. Reproduktion (auch auszugsweise) zum kommerziellen Gebrauch für Vortragszwecke 
 * sind nur mit schriftlicher Bewilligung des Verfassers gestattet.
 */
package ch.bouquet.jpa.domain;

import java.io.Serializable;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Version;

import org.apache.log4j.Logger;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Data-Tier (JPA)<br/>
 * User admininstration (examination question)<br/>
 * Description:<br/>
 * Subcriper business object implemented as plain old java object.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Swiss )
 * @version   1.0 - 25.05.2007
 */
@Entity
@Table( name = "SUBSCRIBER" )
public class Subscriber implements Serializable
{
  /**
   * constant for the logging
   */
  @SuppressWarnings( "unused" )
  private static Logger LOG = Logger.getLogger( Subscriber.class );

  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * subscriber id (primary key)
   */
  @Id
  @GeneratedValue
  @Column( name = "SUBSCRIBER_ID" )
  private int subscriberId;

  /**
   * auth user id (foreign key)
   */
  @ManyToOne( cascade = CascadeType.ALL, fetch = FetchType.EAGER )
  @JoinColumn( name = "AUTH_USER_ID" )
  private AuthUser authUser;

  /**
   * firt name
   */
  @Column( name = "FIRST_NAME" )
  private String firstName;

  /**
   * last name
   */
  @Column( name = "LAST_NAME" )
  private String lastName;

  /**
   * email address
   */
  @Column( name = "EMAIL_ADDRESS" )
  private String emailAddress;

  /**
   * address
   */
  @Column( name = "ADDRESS" )
  private String address;

  /**
   * zip code
   */
  @Column( name = "ZIP" )
  private String zip;

  /**
   * city
   */
  @Column( name = "CITY" )
  private String city;

  /**
   * country
   */
  @Column( name = "COUNTRY" )
  private String country;
  
  /**
   * enity version
   */
  @Column( name = "VERSION" )
  @Version
  private long entityVersion;

  //-----------------------------------------------------------------------------
  // C O N S T R U C T O R S
  //-----------------------------------------------------------------------------

  /**
   * Default constructor
   */
  public Subscriber()
  {
    // Don't do anything
  }

  /**
   * Constructor
   * @param firstName String
   * @param lastName String
   * @param emailAddress String
   */
  public Subscriber( String firstName, String lastName, String emailAddress )
  {
    setFirstName( firstName );
    setLastName( lastName );
    setEmailAddress( emailAddress );
  }

  //---------------------------------------------------------------------------
  // toString() method
  //---------------------------------------------------------------------------

  /**
   * Return all attributes as String
   * @return Object as String
   */
  @Override
  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append( " --- toString() of ch.bouquet.jpa.domain.Subscriber ----------------------\n" );
    buf.append( "  subscriber id          <" );
    buf.append( getSubscriberId() );
    buf.append( ">\n" );
    buf.append( "  first name             <" );
    buf.append( getFirstName() );
    buf.append( ">\n" );
    buf.append( "  last name              <" );
    buf.append( getLastName() );
    buf.append( ">\n" );
    buf.append( "  email address          <" );
    buf.append( getEmailAddress() );
    buf.append( ">\n" );
    buf.append( "  address                <" );
    buf.append( getAddress() );
    buf.append( ">\n" );
    buf.append( "  zip code               <" );
    buf.append( getZip() );
    buf.append( ">\n" );
    buf.append( "  city                   <" );
    buf.append( getCity() );
    buf.append( ">\n" );
    buf.append( "  country                <" );
    buf.append( getCountry() );
    buf.append( ">\n" );
    buf.append( "  enitity version        <" );
    buf.append( getEntityVersion() );
    buf.append( ">\n" );
    buf.append( "\n  auth user element      <1>\n" );
    buf.append( getAuthUser().toString() );
    buf.append( "\n -------------------------------------------------------------------------" );
    return buf.toString();
  }

  /**
   * Return a formatted subscriber as String
   * @return Object as String
   */
  public String toStringFormatted()
  {
    StringBuilder buf = new StringBuilder();
    buf.append( "--- Registrierungsdaten des Benutzer <" );
    buf.append( getSubscriberId() );
    buf.append( "> --------------------------------\n" );
    buf.append( getFirstName() );
    buf.append( " " );
    buf.append( getLastName() );
    buf.append( "\n" );
    buf.append( getAddress() );
    buf.append( "\n" );
    buf.append( getCountry() );
    buf.append( "-" );
    buf.append( getZip() );
    buf.append( " " );
    buf.append( getCity() );
    buf.append( "\n" );
    buf.append( getEmailAddress() );
    buf.append( "\n-------------------------------------------------------------------------" );
    return buf.toString();
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - / S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Gets the subscriberId.
   * @return the subscriberId
   */
  public int getSubscriberId()
  {
    return this.subscriberId;
  }

  /**
   * Sets the subscriberId.
   * @param subscriberId The subscriberId to set
   */
  public void setSubscriberId( int subscriberId )
  {
    this.subscriberId = subscriberId;
  }

  /**
   * Gets the authUser.
   * @return the authUser
   */
  public AuthUser getAuthUser()
  {
    return this.authUser;
  }

  /**
   * Sets the authUser.
   * @param authUser The authUser to set
   */
  public void setAuthUser( AuthUser authUser )
  {
    this.authUser = authUser;
  }

  /**
   * Gets the firstName.
   * @return the firstName
   */
  public String getFirstName()
  {
    return this.firstName;
  }

  /**
   * Sets the firstName.
   * @param firstName The firstName to set
   */
  public void setFirstName( String firstName )
  {
    this.firstName = firstName;
  }

  /**
   * Gets the lastName.
   * @return the lastName
   */
  public String getLastName()
  {
    return this.lastName;
  }

  /**
   * Sets the lastName.
   * @param lastName The lastName to set
   */
  public void setLastName( String lastName )
  {
    this.lastName = lastName;
  }

  /**
   * Gets the emailAddress.
   * @return the emailAddress
   */
  public String getEmailAddress()
  {
    return this.emailAddress;
  }

  /**
   * Sets the emailAddress.
   * @param emailAddress The emailAddress to set
   */
  public void setEmailAddress( String emailAddress )
  {
    this.emailAddress = emailAddress;
  }

  /**
   * Gets the address.
   * @return the address
   */
  public String getAddress()
  {
    return this.address;
  }

  /**
   * Sets the address.
   * @param address The address to set
   */
  public void setAddress( String address )
  {
    this.address = address;
  }

  /**
   * Gets the zip.
   * @return the zip
   */
  public String getZip()
  {
    return this.zip;
  }

  /**
   * Sets the zip.
   * @param zip The zip to set
   */
  public void setZip( String zip )
  {
    this.zip = zip;
  }

  /**
   * Gets the city.
   * @return the city
   */
  public String getCity()
  {
    return this.city;
  }

  /**
   * Sets the city.
   * @param city The city to set
   */
  public void setCity( String city )
  {
    this.city = city;
  }

  /**
   * Gets the country.
   * @return the country
   */
  public String getCountry()
  {
    return this.country;
  }

  /**
   * Sets the country.
   * @param country The country to set
   */
  public void setCountry( String country )
  {
    this.country = country;
  }
  
  /**
   * Gets the entity version.
   * @return the entity version
   */
  public long getEntityVersion()
  {
    return this.entityVersion;
  }

  /**
   * Sets the entity version.
   * @param entityVersion The entity version to set
   */
  public void setEntityVersion( long entityVersion )
  {
    this.entityVersion = entityVersion;
  }
}