package ch.bouquet.jpa.persistence;

import java.io.Serializable;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.Query;

import org.apache.log4j.Logger;

import ch.bouquet.jpa.domain.AuthUser;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Data-Tier (JPA)<br/>
 * User admininstration (examination question)<br/>
 * Description:<br/>
 * This class encases the inquiries by JPQL on the table auth_user
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Swiss )
 * @version   1.0 - 04.06.2007
 */
public class AuthUserBean implements Serializable
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  @SuppressWarnings( "unused" )
  private static Logger LOG = Logger.getLogger( AuthUserBean.class );

  /**
   * The entity manager
   */
  private EntityManager em = null;

  /**
   * Default constructor.
   * @param em EntityManager
   */
  public AuthUserBean( EntityManager em )
  {
    this.em = em;
  }

  /**
   * This method returns a data record
   * on the basis the SQL instruction.
   * @param sql String SQL-Query
   * @throws NoResultException
   * @return authenticated user found
   */
  public AuthUser findSingle( String sql ) throws NoResultException
  {
    Query query = em.createQuery( sql );
    AuthUser result = (AuthUser) query.getSingleResult();
    return result != null ? result : null;
  }

  /**
   * This method returns the number of data records
   * on the basis the SQL instruction.
   * @param sql String SQL-Query
   * @return size of count [0] or [n] hits
   */
  public long findSize( String sql )
  {
    Query query = em.createQuery( sql );
    long count = (Long) query.getSingleResult();
    return count;
  }

  /**
   * This method returns all data records
   * on the basis the SQL instruction.
   * @param sql String SQL-Query
   * @return list of authenticated users or null
   */
  public List<AuthUser> findList( String sql )
  {
    Query query = em.createQuery( sql );
    List<AuthUser> results = query.getResultList();
    return results;
  }

  /**
   * Remove the authenticated user for the given key if available.
   * @param id primary key
   * @throws NoResultException
   * @return true=removed, false=can't removed
   */
  public boolean remove( int id ) throws NoResultException
  {
    // find authenticated user or log a warning
    AuthUser authUser = em.find( AuthUser.class, id );
    // remove authenticated user
    if ( authUser != null )
    {
      em.remove( authUser );
    }
    return authUser != null ? true : false;
  }

  /**
   * Insert new or update existing authenticated user using the given entity and 
   * return the persistet fields of the authenticated user.
   * @param authUser to save
   * @throws NoResultException
   * @return authUser saved or updated
   */
  public AuthUser save( AuthUser authUser ) throws NoResultException
  {
    if ( LOG.isInfoEnabled() )
    {
      LOG.info( "save - authenticated user <" + authUser.toString() + ">" );
    }

    AuthUser result;
    if ( em.find( AuthUser.class, authUser.getAuthUserId() ) == null )
    {
      // insert new entry
      em.persist( authUser );
      result = authUser;
    }
    else
    {
      // update existing entry
      result = em.merge( authUser );
    }
    return result;
  }
}
