package ch.bouquet.jpa.persistence;

import java.io.Serializable;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.Query;

import org.apache.log4j.Logger;

import ch.bouquet.jpa.domain.Search;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Data-Tier (JPA)<br/>
 * User admininstration (examination question)<br/>
 * Description:<br/>
 * This class encases the inquiries by JPQL on the table search
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Swiss )
 * @version   1.0 - 04.06.2007
 */
public class SearchBean implements Serializable
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  //TODO: Java-Doc anpassen
  /**
   * constant for the logging
   */
  @SuppressWarnings( "unused" )
  private static Logger LOG = Logger.getLogger( SearchBean.class );

  /**
   * The entity manager
   */
  private EntityManager em = null;

  /**
   * Default constructor.
   * @param em EntityManager
   */
  public SearchBean( EntityManager em )
  {
    this.em = em;
  }

  /**
   * This method returns a data record
   * on the basis the SQL instruction.
   * @param sql String SQL-Query
   * @throws NoResultException
   * @return search found
   */
  public Search findSingle( String sql ) throws NoResultException
  {
    Query query = em.createQuery( sql );
    Search result = (Search) query.getSingleResult();
    return result != null ? result : null;
  }

  /**
   * This method returns all data records
   * on the basis the SQL instruction.
   * @param sql String SQL-Query
   * @return list of searchs or null
   */
  public List<Search> findList( String sql )
  {
    Query query = em.createQuery( sql );
    List<Search> results = query.getResultList();
    return results;
  }

  /**
   * Remove the search for the given key if available.
   * @param id primary key
   * @throws NoResultException
   * @return true=removed, false=can't removed
   */
  public boolean remove( int id ) throws NoResultException
  {
    // find authenticated user or log a warning
    Search search = em.find( Search.class, id );
    // remove search
    if ( search != null )
    {
      em.remove( search );
    }
    return search != null ? true : false;
  }

  /**
   * Insert new or update existing search using the given entity and 
   * return the persistet fields of the search.
   * @param search to save
   * @throws NoResultException
   * @return search saved or updated
   */
  public Search save( Search search ) throws NoResultException
  {
    Search result;
    if ( em.find( Search.class, search.getSearchId() ) == null )
    {
      // insert new entry
      em.persist( search );
      result = search;
    }
    else
    {
      // update existing entry
      result = em.merge( search );
    }
    return result;
  }
}