package ch.bouquet.jpa.persistence;

import java.io.Serializable;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.Query;

import org.apache.log4j.Logger;

import ch.bouquet.jpa.domain.Subscriber;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Data-Tier (JPA)<br/>
 * User admininstration (examination question)<br/>
 * Description:<br/>
 * This class encases the inquiries by JPQL on the table subscriber
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Swiss )
 * @version   1.0 - 04.06.2007
 */
public class SubscriberBean implements Serializable
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  //TODO: Java-Doc anpassen
  /**
   * constant for the logging
   */
  @SuppressWarnings( "unused" )
  private static Logger LOG = Logger.getLogger( SubscriberBean.class );

  /**
   * The entity manager
   */
  private EntityManager em = null;

  /**
   * Default constructor.
   * @param em EntityManager
   */
  public SubscriberBean( EntityManager em )
  {
    this.em = em;
  }

  /**
   * This method returns a data record
   * on the basis the SQL instruction.
   * @param sql String SQL-Query
   * @throws NoResultException
   * @return subscriber found
   */
  public Subscriber findSingle( String sql ) throws NoResultException
  {
    Query query = em.createQuery( sql );
    Subscriber result = (Subscriber) query.getSingleResult();
    return result != null ? result : null;
  }

  /**
   * This method returns all data records
   * on the basis the SQL instruction.
   * @param sql String SQL-Query
   * @return list of subscribers or null
   */
  public List<Subscriber> findList( String sql )
  {
    Query query = em.createQuery( sql );
    List<Subscriber> results = query.getResultList();
    return results;
  }

  /**
   * Remove the subscriber for the given key if available.
   * @param id primary key
   * @throws NoResultException
   * @return true=removed, false=can't removed
   */
  public boolean remove( int id ) throws NoResultException
  {
    // find Subscriber or log a warning
    Subscriber subscriber = em.find( Subscriber.class, id );
    // remove subscriber
    if ( subscriber != null )
    {
      em.remove( subscriber );
    }
    return subscriber != null ? true : false;
  }

  /**
   * Insert new or update existing subscriber using the given entity and 
   * return the persistet fields of the subscriber.
   * @param subscriber to save
   * @throws NoResultException
   * @return subscriber saved or updated
   */
  public Subscriber save( Subscriber subscriber ) throws NoResultException
  {
    Subscriber result;
    if ( em.find( Subscriber.class, subscriber.getSubscriberId() ) == null )
    {
      // insert new entry
      em.persist( subscriber );
      result = subscriber;
    }
    else
    {
      // update existing entry
      result = em.merge( subscriber );
    }
    return result;
  }
}