package ch.bouquet.jpa.util;

import java.sql.Timestamp;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.StringTokenizer;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Data-Tier (JPA)<br/>
 * User admininstration (examination question)<br/>
 * Description:<br/>
 * date helper class to format date strings into timestamps and vice versa.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Swiss )
 * @version   1.0 - 25.05.2007
 */
public class DateHelper
{
  /**
   * Date separator string, used to parse date strings
   */
  public static final String DATE_SEPARATOR = ".";

  /**
   * Date string format in days, month and years
   */
  public static final String DATE_FORMAT = "dd.MM.yyyy";

  /**
   * Date string format in days, month, years, hours, minute and secounds
   */
  public static final String DATE_FORMAT_COMPLIT = "dd.MM.yyyy HH:mm:ss";

  /**
   * Year format including centruy
   */
  public static final String YEAR_FORMAT = "yyyy";

  /**
   * Convert date string with the format dd.mm.yyyy to a calendar type
   * @param date as string
   * @return calendar
   */
  public static Calendar toCalendar( String date )
  {
    StringTokenizer st = new StringTokenizer( date, DATE_SEPARATOR );
    Calendar cal = Calendar.getInstance();
    cal.set( Calendar.DAY_OF_MONTH, Integer.parseInt( st.nextToken() ) );
    cal.set( Calendar.MONTH, Integer.parseInt( st.nextToken() ) - 1 );
    cal.set( Calendar.YEAR, Integer.parseInt( st.nextToken() ) );
    cal.set( Calendar.HOUR_OF_DAY, 0 );
    cal.set( Calendar.MINUTE, 0 );
    cal.set( Calendar.SECOND, 0 );
    return cal;
  }

  /**
   * Convert date string with the format dd.mm.yyyy to a timestamp type
   * @param date as string
   * @return timestamp
   */
  public static Timestamp toTimestamp( String date )
  {
    return new Timestamp( toCalendar( date ).getTimeInMillis() );
  }

  /**
   * return timestamp as date in the format dd.mm.yyyy or an empty string if
   * the timestamp is null 
   * @param timestamp given timestamp
   * @return String timestamp as date string or empty string if null
   */
  public static String toString( Timestamp timestamp )
  {
    if ( timestamp == null )
    {
      return "";
    }
    Calendar cal = Calendar.getInstance();
    cal.setTimeInMillis( timestamp.getTime() );
    return toString( cal );
  }

  /**
   * return calendar as date in the format dd.mm.yyyy or an empty string if
   * calendar is null.
   * @param calendar given calendar
   * @return String calendar as date string or empty string if null
   */
  private static String toString( Calendar calendar )
  {
    if ( calendar == null )
    {
      return "";
    }
    StringBuilder buf = new StringBuilder();
    buf.append( addLeadingZero( calendar.get( Calendar.DAY_OF_MONTH ), 2 ) );
    buf.append( "." );
    buf.append( addLeadingZero( calendar.get( Calendar.MONTH ) + 1, 2 ) );
    buf.append( "." );
    buf.append( calendar.get( Calendar.YEAR ) );
    return buf.toString();
  }

  /**
   * return date as string in the format dd.mm.yyyy HH:mm:ss or an empty string if
   * date is null.
   * @param date Date
   * @return String formatted date as string or empty string if null
   */
  public static String toString( Date date )
  {
    DateFormat df = new SimpleDateFormat( "dd.MM.yyyy HH:mm:ss" );
    return df.format( date );
  }

  /**
   * add leading zero's to a given string
   * @param text given string (sample = "2")
   * @param len total length of new string (sample = 3)
   * @return String new string with leading zeros (sample = "002")
   */
  private static String addLeadingZero( int text, int len )
  {
    StringBuilder buf = new StringBuilder( len );
    buf.append( text );
    while ( buf.length() < len )
    {
      buf.insert( 0, '0' );
    }
    return buf.toString();
  }
}